import { includeBytes } from "fastly:experimental";
import { InlineStoreEntry } from "../kv-store/inline-store-entry.js";
import { ContentAssets, findMatchingSourceAndInfo } from "./content-assets.js";
const decoder = new TextDecoder();
export class ContentWasmInlineAsset {
    constructor(metadata) {
        this.type = 'wasm-inline';
        this.metadata = metadata;
        this.sourceAndInfo = {
            source: includeBytes(metadata.fileInfo.staticFilePath),
            hash: metadata.fileInfo.hash,
            size: metadata.fileInfo.size,
        };
        this.compressedSourcesAndInfo = Object.entries(metadata.compressedFileInfos)
            .reduce((obj, [key, value]) => {
            obj[key] = {
                source: includeBytes(value.staticFilePath),
                hash: value.hash,
                size: value.size,
            };
            return obj;
        }, {});
    }
    get isLocal() {
        return true;
    }
    get assetKey() {
        return this.metadata.assetKey;
    }
    async getStoreEntry(acceptEncodingsGroups = []) {
        const { sourceAndInfo, contentEncoding } = findMatchingSourceAndInfo(acceptEncodingsGroups, this.sourceAndInfo, encoding => this.compressedSourcesAndInfo[encoding]);
        const { source, hash, size } = sourceAndInfo;
        return new InlineStoreEntry(source, contentEncoding, hash, size);
    }
    getBytes() {
        return this.sourceAndInfo.source;
    }
    getText() {
        if (!this.metadata.text) {
            throw new Error("Can't getText() for non-text content");
        }
        return decoder.decode(this.sourceAndInfo.source);
    }
    getMetadata() {
        return this.metadata;
    }
}
ContentAssets.registerAssetBuilder('wasm-inline', metadata => new ContentWasmInlineAsset(metadata));
